internal

package
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 31, 2025 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Generate

func Generate(src any, dest any) (string, error)

func GenerateDiff

func GenerateDiff(src any, dest any, config string) (string, error)

func GenerateField

func GenerateField(field reflect.StructField, value reflect.Value, reverse bool) (string, error)

func GenerateFieldByPath

func GenerateFieldByPath(parsed any, path string, reverse bool) (string, error)

func GenerateFlat added in v0.0.4

func GenerateFlat(src any, dest any, i int, config string) (string, error)

func GenerateParent

func GenerateParent(src any) (string, error)

func GeneratePart

func GeneratePart(src any, dest any, i int, t reflect.Type, config string) (string, string, error)

func GenerateSubConfig

func GenerateSubConfig(src any, dest any, fieldIndex int, destIndex int, t reflect.Type) (string, string, error)

func GenerateTag

func GenerateTag(parsed any, tag string) (string, error)

func Parse

func Parse(data string, v any) error

func ProcessParse

func ProcessParse(part string, parsed any) error

ProcessParse takes a part of the config and a pointer to a struct with tags on how to parse the config part. ProcessParse can also take a reflect.Value to call itself.

func UnmarshalPart

func UnmarshalPart(t reflect.Type, vValue reflect.Value, part string) error

Types

This section is empty.

Directories

Path Synopsis

Jump to