Documentation
¶
Index ¶
- func Generate(src any, dest any) (string, error)
- func GenerateDiff(src any, dest any, config string) (string, error)
- func GenerateField(field reflect.StructField, value reflect.Value, reverse bool) (string, error)
- func GenerateFieldByPath(parsed any, path string, reverse bool) (string, error)
- func GenerateFlat(src any, dest any, i int, config string) (string, error)
- func GenerateParent(src any) (string, error)
- func GeneratePart(src any, dest any, i int, t reflect.Type, config string) (string, string, error)
- func GenerateSubConfig(src any, dest any, fieldIndex int, destIndex int, t reflect.Type) (string, string, error)
- func GenerateTag(parsed any, tag string) (string, error)
- func Parse(data string, v any) error
- func ProcessParse(part string, parsed any) error
- func UnmarshalPart(t reflect.Type, vValue reflect.Value, part string) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GenerateField ¶
func GenerateFieldByPath ¶
func GenerateFlat ¶ added in v0.0.4
func GenerateParent ¶
func GeneratePart ¶
func GenerateSubConfig ¶
func ProcessParse ¶
ProcessParse takes a part of the config and a pointer to a struct with tags on how to parse the config part. ProcessParse can also take a reflect.Value to call itself.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.